@@ -1,8 +1,6 @@
 # --
 # Kernel/System/DynamicField/ObjectType/Ticket.pm - Ticket object handler for DynamicField
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Ticket.pm,v 1.13 2012/12/03 11:51:01 mg Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,9 +17,6 @@ use Scalar::Util;
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::Ticket;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.13 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField::ObjectType::Ticket
@@ -63,7 +58,7 @@ sub new {
 
         $Self->{TicketObject} = $Param{TicketObject};
 
-     # Make ticket object reference weak so it will not count as a reference on objetcs destroy.
+     # Make ticket object reference weak so it will not count as a reference on objects destroy.
      #   This is because the TicketObject has a Kernel::DynamicField::Backend object, which has this
      #   object, which has a TicketObject again. Without weaken() we'd have a cyclic reference.
         Scalar::Util::weaken( $Self->{TicketObject} );
@@ -81,7 +76,7 @@ sub new {
 
 =item PostValueSet()
 
-perform specific fuctions after the Value set for this object type.
+perform specific functions after the Value set for this object type.
 
     my $Success = $DynamicFieldTicketHandlerObject->PostValueSet(
         DynamicFieldConfig => $DynamicFieldConfig,      # complete config of the DynamicField
@@ -144,13 +139,52 @@ sub PostValueSet {
     );
     $HistoryValue = $ValueStrg->{Value};
 
+    my $FieldName;
+    if ( !defined $Param{DynamicFieldConfig}->{Name} ) {
+        $FieldName = '',
+    }
+    else {
+        $FieldName = $Param{DynamicFieldConfig}->{Name};
+    }
+
+    my $FieldNameLength    = length($FieldName);
+    my $HistoryValueLength = length($HistoryValue);
+
+    # Name in ticket_history is like this form  "\%\%FieldName\%\%$FieldName\%\%Value\%\%$HistoryValue" up to 200 chars
+    # \%\%FieldName\%\% is 13 chars
+    # \%\%Value\%\% is 9 chars
+    # we have for info part of ticket history data ($FieldName+$HistoryValue) up to 178 chars
+    # in this code is made substring. The same number of characters is provided for both of part in Name ($FieldName and $HistoryValue) up to 84 chars
+    # First it is made $FieldName, then it is made $HistoryValue.
+    # Length $HistoryValue is rest to 168 chars, because it is added "[...]" on substrig, and there is no 178 chars than 168.
+    # If $FieldName wasn't cut and not added [...] then rest for $HistoryValue is 173 instead 168
+    # Length $HistoryValue can be longer then 83 chars
+
+    my $NoCharacters = 178;
+
+    if ( ( $FieldNameLength + $HistoryValueLength ) > 178 ) {
+
+        # limit FieldName to 84 chars if is necessary
+        if ( length($FieldName) > 84 ) {
+            $FieldName = substr( $FieldName, 0, 84 );
+            $FieldName .= '[...]';
+        }
+
+        my $ValueLength = $NoCharacters - length($FieldName);
+        if ( length($HistoryValue) > $ValueLength ) {
+            $ValueLength -= 5;
+            $HistoryValue = substr( $HistoryValue, 0, $ValueLength );
+            $HistoryValue .= '[...]';
+        }
+    }
+
     # history insert
     $Self->{TicketObject}->HistoryAdd(
         TicketID    => $Param{ObjectID},
         QueueID     => $Ticket{QueueID},
         HistoryType => 'TicketDynamicFieldUpdate',
         Name =>
-            "\%\%FieldName\%\%$Param{DynamicFieldConfig}->{Name}\%\%Value\%\%$HistoryValue",
+            "\%\%FieldName\%\%$FieldName\%\%Value\%\%$HistoryValue",
         CreateUserID => $Param{UserID},
     );
 
@@ -185,9 +219,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.13 $ $Date: 2012/12/03 11:51:01 $
-
-=cut
