@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Stats/Dynamic/Ticket.pm - all advice functions
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -75,10 +75,17 @@ sub GetObjectBehaviours {
 sub GetObjectAttributes {
     my ( $Self, %Param ) = @_;
 
+    my $ValidAgent = 0;
+    if ( defined $Self->{ConfigObject}->Get('Stats::UseInvalidAgentInStats')
+        && ( $Self->{ConfigObject}->Get('Stats::UseInvalidAgentInStats') == 0 ) )
+    {
+        $ValidAgent = 1;
+    }
+
     # get user list
     my %UserList = $Self->{UserObject}->UserList(
         Type  => 'Long',
-        Valid => 0,
+        Valid => $ValidAgent,
     );
 
     # get state list
