@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # --
 # bin/otrs.PendingJobs.pl - check pending tickets
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -56,12 +56,17 @@ $CommonObject{StateObject}  = Kernel::System::State->new(%CommonObject);
 # check args
 my $Command = shift || '--help';
 print "otrs.PendingJobs.pl - check pending tickets\n";
-print "Copyright (C) 2001-2013 OTRS AG, http://otrs.com/\n";
+print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n";
+
+my @PendingAutoStateIDs = $CommonObject{StateObject}->StateGetStatesByType(
+     Type   => 'PendingAuto',
+     Result => 'ID',
+);
 
 # do ticket auto jobs
 my @TicketIDs = $CommonObject{TicketObject}->TicketSearch(
     Result    => 'ARRAY',
-    StateType => 'pending auto',
+    StateIDs => [@PendingAutoStateIDs],
     UserID    => 1,
 );
 
@@ -215,8 +220,8 @@ for my $TicketID (@TicketIDs) {
         my $Sent = 0;
         for my $Line (@Lines) {
             if (
-                $Line->{Name}          =~ /PendingReminder/
-                && $Line->{Name}       =~ /\Q$Preferences{UserEmail}\E/i
+                $Line->{Name} =~ /PendingReminder/
+                && $Line->{Name} =~ /\Q$Preferences{UserEmail}\E/i
                 && $Line->{CreateTime} =~ /$Year-$Month-$Day/
                 )
             {
